{
    "$graph": [
        {
            "class": "Workflow",
            "label": "varscan somatic workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/normal_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/roi_bed"
                },
                {
                    "type": "File",
                    "id": "#main/tumor_bam"
                }
            ],
            "steps": [
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#main/somatic/indels",
                            "id": "#main/process_somatic_indels/variants"
                        }
                    ],
                    "out": [
                        "#main/process_somatic_indels/somatic_hc",
                        "#main/process_somatic_indels/somatic",
                        "#main/process_somatic_indels/germline_hc",
                        "#main/process_somatic_indels/germline",
                        "#main/process_somatic_indels/loh_hc",
                        "#main/process_somatic_indels/loh"
                    ],
                    "id": "#main/process_somatic_indels"
                },
                {
                    "run": "#varscan_processsomatic.cwl",
                    "in": [
                        {
                            "source": "#main/somatic/snvs",
                            "id": "#main/process_somatic_snvs/variants"
                        }
                    ],
                    "out": [
                        "#main/process_somatic_snvs/somatic_hc",
                        "#main/process_somatic_snvs/somatic",
                        "#main/process_somatic_snvs/germline_hc",
                        "#main/process_somatic_snvs/germline",
                        "#main/process_somatic_snvs/loh_hc",
                        "#main/process_somatic_snvs/loh"
                    ],
                    "id": "#main/process_somatic_snvs"
                },
                {
                    "run": "#varscan_somatic.cwl",
                    "in": [
                        {
                            "source": "#main/normal_bam",
                            "id": "#main/somatic/normal_bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/somatic/reference"
                        },
                        {
                            "source": "#main/roi_bed",
                            "id": "#main/somatic/roi_bed"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/somatic/tumor_bam"
                        }
                    ],
                    "out": [
                        "#main/somatic/snvs",
                        "#main/somatic/indels"
                    ],
                    "id": "#main/somatic"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/germline_hc",
                    "id": "#main/germline_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/germline_hc",
                    "id": "#main/germline_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/germline",
                    "id": "#main/germline_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/germline",
                    "id": "#main/germline_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/somatic/indels",
                    "id": "#main/indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/loh_hc",
                    "id": "#main/loh_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/loh_hc",
                    "id": "#main/loh_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/loh",
                    "id": "#main/loh_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/loh",
                    "id": "#main/loh_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/somatic/snvs",
                    "id": "#main/snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/somatic_hc",
                    "id": "#main/somatic_hc_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/somatic_hc",
                    "id": "#main/somatic_hc_snvs"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_indels/somatic",
                    "id": "#main/somatic_indels"
                },
                {
                    "type": "File",
                    "outputSource": "#main/process_somatic_snvs/somatic",
                    "id": "#main/somatic_snvs"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 processSomatic",
            "baseCommand": [
                "java",
                "-jar",
                "/opt/varscan/VarScan.jar",
                "processSomatic"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/varscan-cwl:v2.4.2-samtools1.3.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.variants)"
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(runtime.outdir)/$(self.basename)",
                        "position": 1
                    },
                    "id": "#varscan_processsomatic.cwl/variants"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Germline.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/germline_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.LOH.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/loh_hc"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.Somatic.hc.vcf"
                    },
                    "id": "#varscan_processsomatic.cwl/somatic_hc"
                }
            ],
            "id": "#varscan_processsomatic.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 somatic",
            "baseCommand": "/usr/bin/cwl_helper.sh",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/varscan-cwl:v2.4.2-samtools1.3.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#varscan_somatic.cwl/normal_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#varscan_somatic.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_somatic.cwl/roi_bed"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#varscan_somatic.cwl/tumor_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.indel.vcf"
                    },
                    "id": "#varscan_somatic.cwl/indels"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.snp.vcf"
                    },
                    "id": "#varscan_somatic.cwl/snvs"
                }
            ],
            "id": "#varscan_somatic.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
